Files
odfstudio/sw/source/core/SwNumberTree
Noel Grandin 0e47a21503 improve SwNumberTreeNode::MoveChildren perf (ofz#422030803 related)
Use o3tl::sorted_vector instead of std::set,
the sets are fairly small here,
and cache effects dominate.

Takes the test for this test file from 7.6s to 0.6s

Change-Id: I7fad3cd20ab1df01b11273e5f841109fc846433e
Reviewed-on: https://gerrit.libreoffice.org/c/core/+/202152
Tested-by: Jenkins
Reviewed-by: Noel Grandin <noel.grandin@collabora.co.uk>
2026-03-19 16:28:33 +01:00
..